@@ -21,25 +21,26 @@ from . import module_register, module_config_register, Module
 
 @module_config_register("logits_gather")
 class LogitsGatherConfig(BaseConfig):
+    default_config = {
+            "config": {
+                "gather_layer": {
+                    # "0": {
+                    #     "map": "3", # the 0th layer not do scale output to "gather_logits_3", "gather_logits_" is the output name prefix, the "3" is map name
+                    #     "scale": {} # don't scale
+                    # },
+                    # "1": {
+                    #     "map": "4",  # the 1th layer scale output dim from 1024 to 200 and the output named "gather_logits_3"
+                    #     "scale": {"1024":"200"},
+                    # }
+                },
+                "prefix": "gather_logits_",
+            },
+            "_name": "logits_gather",
+        }
     """Config for LogitsGather
 
     Config Example:
-        >>> {
-        >>>     "config": {
-        >>>         "gather_layer": {
-        >>>             "0": {
-        >>>                 "map": "3", // the 0th layer not do scale output to "gather_logits_3", "gather_logits_" is the output name prefix, the "3" is map name
-        >>>                 "scale": {} //don't scale
-        >>>             },
-        >>>             "1": {
-        >>>                 "map": "4",  // the 1th layer scale output dim from 1024 to 200 and the output named "gather_logits_3"
-        >>>                 "scale": {"1024":"200"},
-        >>>             }
-        >>>         },
-        >>>         "prefix": "gather_logits_",
-        >>>     },
-        >>>     _name: "logits_gather",
-        >>> }
+        default_config
     """
     def __init__(self, config: Dict):
         if '_name' not in config:
@@ -72,6 +73,12 @@ class LogitsGather(Module):
                 for from_dim, to_dim in scale.items:
                     self.layers_scale[str(layer)] = nn.Linear(int(from_dim), int(to_dim))
 
+        if not self.layer_map:
+            self.pass_gather = True
+        else:
+            self.pass_gather = False
+
+
     def forward(self, input: List[torch.Tensor])->Dict[str, torch.Tensor]:
         """gather the needed input to dict
 
@@ -84,7 +91,7 @@ class LogitsGather(Module):
         """
         result = torch.jit.annotate(Dict[str, torch.Tensor], {})
 
-        if not self.layer_map:
+        if self.pass_gather:
             return result
         for layer, layer_suffix in self.layer_map.items():
             if layer in self.layers_scale:
